@@ -1,6 +1,6 @@
 from django.conf.urls import url
-from .views import CirclesJoinableViewset, CirclesRequestableViewset, CircleAccessRequestServerNotificationView
-from .models import Circle
+from .views import CirclesJoinableViewset, CirclesRequestableViewset, CircleAccessRequestServerNotificationView, CircleAccessRequestFilteredByUserViewSet
+from .models import Circle, CircleAccessRequest
 from djangoldp.models import Model
 
 
@@ -17,5 +17,11 @@ urlpatterns = [
         permission_classes=Model.get_meta(Circle, 'permission_classes', []),
         fields=Model.get_meta(Circle, 'serializer_fields', []),
         nested_fields=Model.get_meta(Circle, 'nested_fields', []))),
-    url(r'circleaccessrequests/inbox/', CircleAccessRequestServerNotificationView.as_view(), name='circle-notifications-inbox')
+    url(r'circleaccessrequests/inbox/', CircleAccessRequestServerNotificationView.as_view(), name='circle-notifications-inbox'),
+    url(r'circleaccessrequests/me/', CircleAccessRequestFilteredByUserViewSet.urls(model_prefix="circlesaccessrequests-me",
+        model=CircleAccessRequest,
+        lookup_field=Model.get_meta(CircleAccessRequest, 'lookup_field', 'pk'),
+        permission_classes=Model.get_meta(CircleAccessRequest, 'permission_classes', []),
+        fields=Model.get_meta(CircleAccessRequest, 'serializer_fields', []),
+        nested_fields=Model.get_meta(CircleAccessRequest, 'nested_fields', []))),
 ]
