@@ -14,6 +14,7 @@ from django.dispatch import receiver
 from django.template import loader
 from djangoldp.activities.services import ActivityQueueService
 from djangoldp.models import Model
+from django.utils.encoding import force_text
 from djangoldp_circle.permissions import CirclePermissions, CircleMemberPermissions, CircleAccessRequestPermissions
 from djangoldp_circle.views import CircleMembersViewset
 import logging
@@ -251,36 +252,36 @@ if 'djangoldp_notification' in settings.DJANGOLDP_PACKAGES:
 
             # when an access request is created, send a notification to Circle administrators
             if ar.status == 'Pending':
-                message_html = render_to_string('accessrequests/access_requested.html', {
+                html_message = render_to_string('accessrequests/access_requested.html', {
                     "instance": ar,
                     'on': on,
                 })
 
                 send_mail(
-                    "Someone requested access to your circle",
-                    to_text(message_html),
+                    _("Someone requested access to your circle"),
+                    to_text(html_message),
                     email_from,
                     [instance.user.email],
                     fail_silently = False,
-                    html_message = message_html
+                    html_message = html_message
                 )
 
             # when an access request is resolved, add the user as a CircleMember if approved,
             # and send a notification to the user who made the request
             else:
-
                 html_message = loader.render_to_string(
                     'accessrequests/access_resolved.html',
                     {
                         'on': on,
-                        'instance': instance,
+                        'instance': ar,
                         'accepted': ar.status == "Accepted"
                     }
                 )
 
+                email_title = (ar.status == "Accepted") if _("Your access request has been accepted") else  _("Your access request has been refused")
                 send_mail(
-                    "Your access request has been " + ar.status,
-                    "",
+                    email_title,
+                    to_text(html_message),
                     email_from,
                     [instance.user.email],
                     fail_silently=(not settings.DEBUG),
@@ -303,27 +304,30 @@ if 'djangoldp_notification' in settings.DJANGOLDP_PACKAGES:
         notification_type = "CircleAccessRequest"
         author = instance.user if created else instance.responded_to_by
         author = author.urlid if author is not None else str(_("Auteur inconnu"))
-        summary = 'New Circle access request' if created else "Circle access request " + instance.status
-
+        summary = (instance.status == "Accepted") if _("Your access request has been accepted") else  _("Your access request has been refused")
+        if created:
+            summary = _('New Circle access request')
+            
         notification = {
             "@context": settings.LDP_RDF_CONTEXT,
             "object": notification_obj,
             "author": author,
             "type": notification_type,
-            "summary": summary
+            "summary": force_text(summary)
         }
 
         def discover_circle_access_requests_inbox(target_urlid):
-            parsed_url = urlparse(target.urlid)
-
+            parsed_url = urlparse(target_urlid)
+            
             # TODO: proper inbox discovery
-            return "{}://{}/circleaccessrequests/inbox/".format(parsed_url.scheme, parsed_url.netloc)
+            distant_server_inbox = "{}://{}/circleaccessrequests/inbox/".format(parsed_url.scheme, parsed_url.netloc)
+            return distant_server_inbox
         
         def send_notification_to_user(user):
             from djangoldp_notification.models import Notification
 
             if Model.is_external(user):
-                inbox = discover_circle_access_requests_inbox(target.urlid)
+                inbox = discover_circle_access_requests_inbox(target.user.urlid)
                 ActivityQueueService.send_activity(inbox, notification)
             else:
                 Notification.objects.create(user=user, object=notification_obj['@id'], author=author, type=notification_type, summary=summary)
@@ -333,8 +337,6 @@ if 'djangoldp_notification' in settings.DJANGOLDP_PACKAGES:
         if created:
             for target in instance.circle.members.filter(is_admin=True):
                 notification['target'] = target.user.urlid
-
                 send_notification_to_user(target.user)
-        
         elif instance.status != "Pending":
             send_notification_to_user(instance.user)
