@@ -27,8 +27,13 @@ class CirclePermissions(LDPPermissions):
         if obj.status == 'Public':
             perms = perms.union({'view'})
 
+            # I can join the public circle
             if is_authenticated_user(user):
                 perms = perms.union({'add'})
+        
+        # I can view - but not automatically join - restricted circles
+        elif obj.status == 'Restricted':
+            perms = perms.union({'view'})
 
         return perms
 
