@@ -7,7 +7,7 @@ from djangoldp.permissions import LDPPermissions
 from rest_framework.test import APITestCase, APIClient
 from guardian.shortcuts import assign_perm
 
-from djangoldp_circle.models import Circle, CircleMember
+from djangoldp_circle.models import Circle, CircleMember, CircleAccessRequest
 from djangoldp_circle.tests.utils import get_random_user
 
 
@@ -92,10 +92,11 @@ class PermissionsTestCase(APITestCase):
         public_circle = self._get_random_circle('Public', another_user)
         my_circle = self._get_random_circle('Private', self.user)
         private_circle = self._get_random_circle('Private', another_user)
+        restricted_circle = self._get_random_circle('Restricted', another_user)
 
         response = self.client.get('/circles/')
         self.assertEqual(response.status_code, 200)
-        self.assertEqual(len(response.data['ldp:contains']), 2)
+        self.assertEqual(len(response.data['ldp:contains']), 3)
 
     # GET circle public
     def test_get_public_circle(self):
@@ -461,3 +462,52 @@ class PermissionsTestCase(APITestCase):
 
         circle = Circle.objects.get(pk=self.circle.pk)
         self.assertEqual(circle.owner.urlid, owner_id)
+    
+    def test_make_access_request(self):
+        self.setUpLoggedInUser()
+        self.setUpCircle('Restrict', get_random_user())
+        
+        payload = self._get_request_json(circle=self.circle.urlid)
+
+        response = self.client.post('/circles/{}/access_requests/'.format(self.circle.pk),
+                                    data=json.dumps(payload), content_type='application/ld+json')
+        self.assertEqual(response.status_code, 201)
+        ar = CircleAccessRequest.objects.filter(user=self.user)[0]
+        self.assertEqual(ar.circle, self.circle)
+
+    def test_accept_access_request(self):
+        self.setUpLoggedInUser()
+        self.setUpCircle('Restrict', get_random_user())
+
+        CircleMember.objects.create(circle=self.circle, user=self.user, is_admin=True)
+        other_user = get_random_user()
+        ar = CircleAccessRequest.objects.create(circle=self.circle, user=other_user, status='Pending')
+        self.assertFalse(CircleMember.objects.filter(user=other_user, circle=self.circle).exists())
+
+        payload = self._get_request_json()
+        payload.update({
+            'status': 'Accepted'
+        })
+
+        response = self.client.patch('/circleaccessrequests/{}/'.format(ar.pk),
+                                     data=json.dumps(payload), content_type='application/ld+json')
+        self.assertEqual(response.status_code, 200)
+        ar = self.circle.access_requests.all()[0]
+        self.assertEqual(ar.status, payload['status'])
+        self.assertTrue(CircleMember.objects.filter(user=other_user, circle=self.circle).exists())
+    
+    def test_respond_access_request_not_admin(self):
+        self.setUpLoggedInUser()
+        self.setUpCircle('Restrict', get_random_user())
+
+        CircleMember.objects.create(circle=self.circle, user=self.user, is_admin=False)
+        ar = CircleAccessRequest.objects.create(circle=self.circle, user=get_random_user(), status='Pending')
+
+        payload = self._get_request_json()
+        payload.update({
+            'status': 'Accepted'
+        })
+
+        response = self.client.patch('/circleaccessrequests/{}/'.format(ar.pk),
+                                     data=json.dumps(payload), content_type='application/ld+json')
+        self.assertEqual(response.status_code, 404)
